==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/cloud/CloudInstance.java <==

package com.clustercontrol.ws.cloud;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>cloudInstance complex typeJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * 
 * <pre>
 * &lt;complexType name="cloudInstance">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="accountResourceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="blockDeviceMappings" type="{http://cloud.ws.clustercontrol.com}blockDeviceMapping" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="cloudTypeId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="cloudUserId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="facilityId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="facilityName" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="flavor" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="imageId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="instanceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="instanceName" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="platform" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="regDate" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="regUser" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="region" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="registState" type="{http://cloud.ws.clustercontrol.com}instanceRegistStateType" minOccurs="0"/>
 *         &lt;element name="state" type="{http://cloud.ws.clustercontrol.com}instanceStateKind" minOccurs="0"/>
 *         &lt;element name="tags" type="{http://cloud.ws.clustercontrol.com}tag" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="templateId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="updateDate" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="updateUser" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="zone" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "cloudInstance", propOrder = {
    "accountResourceId",
    "blockDeviceMappings",
    "cloudTypeId",
    "cloudUserId",
    "facilityId",
    "facilityName",
    "flavor",
    "imageId",
    "instanceId",
    "instanceName",
    "platform",
    "regDate",
    "regUser",
    "region",
    "registState",
    "state",
    "tags",
    "templateId",
    "updateDate",
    "updateUser",
    "zone"
})
public class CloudInstance {

    protected String accountResourceId;
    @XmlElement(nillable = true)
    protected List<BlockDeviceMapping> blockDeviceMappings;
    protected String cloudTypeId;
    protected String cloudUserId;
    protected String facilityId;
    protected String facilityName;
    protected String flavor;
    protected String imageId;
    protected String instanceId;
    protected String instanceName;
    protected String platform;
    protected Long regDate;
    protected String regUser;
    protected String region;
    protected InstanceRegistStateType registState;
    protected InstanceStateKind state;
    @XmlElement(nillable = true)
    protected List<Tag> tags;
    protected String templateId;
    protected Long updateDate;
    protected String updateUser;
    protected String zone;

    /**
     * accountResourceIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceId() {
        return accountResourceId;
    }

    /**
     * accountResourceIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceId(String value) {
        this.accountResourceId = value;
    }

    /**
     * Gets the value of the blockDeviceMappings property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the blockDeviceMappings property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBlockDeviceMappings().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BlockDeviceMapping }
     * 
     * 
     */
    public List<BlockDeviceMapping> getBlockDeviceMappings() {
        if (blockDeviceMappings == null) {
            blockDeviceMappings = new ArrayList<BlockDeviceMapping>();
        }
        return this.blockDeviceMappings;
    }

    /**
     * cloudTypeIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCloudTypeId() {
        return cloudTypeId;
    }

    /**
     * cloudTypeIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCloudTypeId(String value) {
        this.cloudTypeId = value;
    }

    /**
     * cloudUserIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCloudUserId() {
        return cloudUserId;
    }

    /**
     * cloudUserIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCloudUserId(String value) {
        this.cloudUserId = value;
    }

    /**
     * facilityIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFacilityId() {
        return facilityId;
    }

    /**
     * facilityIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFacilityId(String value) {
        this.facilityId = value;
    }

    /**
     * facilityNamevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFacilityName() {
        return facilityName;
    }

    /**
     * facilityNamevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFacilityName(String value) {
        this.facilityName = value;
    }

    /**
     * flavorvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFlavor() {
        return flavor;
    }

    /**
     * flavorvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFlavor(String value) {
        this.flavor = value;
    }

    /**
     * imageIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getImageId() {
        return imageId;
    }

    /**
     * imageIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setImageId(String value) {
        this.imageId = value;
    }

    /**
     * instanceIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceId() {
        return instanceId;
    }

    /**
     * instanceIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceId(String value) {
        this.instanceId = value;
    }

    /**
     * instanceNamevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceName() {
        return instanceName;
    }

    /**
     * instanceNamevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceName(String value) {
        this.instanceName = value;
    }

    /**
     * platformvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platformvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPlatform(String value) {
        this.platform = value;
    }

    /**
     * regDatevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRegDate() {
        return regDate;
    }

    /**
     * regDatevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRegDate(Long value) {
        this.regDate = value;
    }

    /**
     * regUservpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegUser() {
        return regUser;
    }

    /**
     * regUservpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRegUser(String value) {
        this.regUser = value;
    }

    /**
     * regionvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegion() {
        return region;
    }

    /**
     * regionvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRegion(String value) {
        this.region = value;
    }

    /**
     * registStatevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link InstanceRegistStateType }
     *     
     */
    public InstanceRegistStateType getRegistState() {
        return registState;
    }

    /**
     * registStatevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceRegistStateType }
     *     
     */
    public void setRegistState(InstanceRegistStateType value) {
        this.registState = value;
    }

    /**
     * statevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link InstanceStateKind }
     *     
     */
    public InstanceStateKind getState() {
        return state;
    }

    /**
     * statevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceStateKind }
     *     
     */
    public void setState(InstanceStateKind value) {
        this.state = value;
    }

    /**
     * Gets the value of the tags property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tags property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTags().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Tag }
     * 
     * 
     */
    public List<Tag> getTags() {
        if (tags == null) {
            tags = new ArrayList<Tag>();
        }
        return this.tags;
    }

    /**
     * templateIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemplateId() {
        return templateId;
    }

    /**
     * templateIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemplateId(String value) {
        this.templateId = value;
    }

    /**
     * updateDatevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUpdateDate() {
        return updateDate;
    }

    /**
     * updateDatevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUpdateDate(Long value) {
        this.updateDate = value;
    }

    /**
     * updateUservpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUpdateUser() {
        return updateUser;
    }

    /**
     * updateUservpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUpdateUser(String value) {
        this.updateUser = value;
    }

    /**
     * zonevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getZone() {
        return zone;
    }

    /**
     * zonevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setZone(String value) {
        this.zone = value;
    }

}

==> CloudClientStandardAWS_v2.0.5.zip: com/clustercontrol/ws/cloud/CloudInstance.java <==

package com.clustercontrol.ws.cloud;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>cloudInstance complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="cloudInstance">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="accountResourceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="blockDeviceMappings" type="{http://cloud.ws.clustercontrol.com}blockDeviceMapping" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="cloudTypeId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="cloudUserId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="facilityId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="facilityName" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="flavor" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="imageId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="instanceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="instanceName" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="platform" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="regDate" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="regUser" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="region" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="registState" type="{http://cloud.ws.clustercontrol.com}instanceRegistStateType" minOccurs="0"/>
 *         &lt;element name="state" type="{http://cloud.ws.clustercontrol.com}instanceStateKind" minOccurs="0"/>
 *         &lt;element name="tags" type="{http://cloud.ws.clustercontrol.com}tag" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="templateId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="updateDate" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="updateUser" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="zone" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "cloudInstance", propOrder = {
    "accountResourceId",
    "blockDeviceMappings",
    "cloudTypeId",
    "cloudUserId",
    "facilityId",
    "facilityName",
    "flavor",
    "imageId",
    "instanceId",
    "instanceName",
    "platform",
    "regDate",
    "regUser",
    "region",
    "registState",
    "state",
    "tags",
    "templateId",
    "updateDate",
    "updateUser",
    "zone"
})
public class CloudInstance {

    protected String accountResourceId;
    @XmlElement(nillable = true)
    protected List<BlockDeviceMapping> blockDeviceMappings;
    protected String cloudTypeId;
    protected String cloudUserId;
    protected String facilityId;
    protected String facilityName;
    protected String flavor;
    protected String imageId;
    protected String instanceId;
    protected String instanceName;
    protected String platform;
    protected Long regDate;
    protected String regUser;
    protected String region;
    protected InstanceRegistStateType registState;
    protected InstanceStateKind state;
    @XmlElement(nillable = true)
    protected List<Tag> tags;
    protected String templateId;
    protected Long updateDate;
    protected String updateUser;
    protected String zone;

    /**
     * accountResourceIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceId() {
        return accountResourceId;
    }

    /**
     * accountResourceIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceId(String value) {
        this.accountResourceId = value;
    }

    /**
     * Gets the value of the blockDeviceMappings property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the blockDeviceMappings property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBlockDeviceMappings().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BlockDeviceMapping }
     * 
     * 
     */
    public List<BlockDeviceMapping> getBlockDeviceMappings() {
        if (blockDeviceMappings == null) {
            blockDeviceMappings = new ArrayList<BlockDeviceMapping>();
        }
        return this.blockDeviceMappings;
    }

    /**
     * cloudTypeIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCloudTypeId() {
        return cloudTypeId;
    }

    /**
     * cloudTypeIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCloudTypeId(String value) {
        this.cloudTypeId = value;
    }

    /**
     * cloudUserIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCloudUserId() {
        return cloudUserId;
    }

    /**
     * cloudUserIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCloudUserId(String value) {
        this.cloudUserId = value;
    }

    /**
     * facilityIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFacilityId() {
        return facilityId;
    }

    /**
     * facilityIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFacilityId(String value) {
        this.facilityId = value;
    }

    /**
     * facilityNameプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFacilityName() {
        return facilityName;
    }

    /**
     * facilityNameプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFacilityName(String value) {
        this.facilityName = value;
    }

    /**
     * flavorプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFlavor() {
        return flavor;
    }

    /**
     * flavorプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFlavor(String value) {
        this.flavor = value;
    }

    /**
     * imageIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getImageId() {
        return imageId;
    }

    /**
     * imageIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setImageId(String value) {
        this.imageId = value;
    }

    /**
     * instanceIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceId() {
        return instanceId;
    }

    /**
     * instanceIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceId(String value) {
        this.instanceId = value;
    }

    /**
     * instanceNameプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceName() {
        return instanceName;
    }

    /**
     * instanceNameプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceName(String value) {
        this.instanceName = value;
    }

    /**
     * platformプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platformプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPlatform(String value) {
        this.platform = value;
    }

    /**
     * regDateプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRegDate() {
        return regDate;
    }

    /**
     * regDateプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRegDate(Long value) {
        this.regDate = value;
    }

    /**
     * regUserプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegUser() {
        return regUser;
    }

    /**
     * regUserプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRegUser(String value) {
        this.regUser = value;
    }

    /**
     * regionプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegion() {
        return region;
    }

    /**
     * regionプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRegion(String value) {
        this.region = value;
    }

    /**
     * registStateプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link InstanceRegistStateType }
     *     
     */
    public InstanceRegistStateType getRegistState() {
        return registState;
    }

    /**
     * registStateプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceRegistStateType }
     *     
     */
    public void setRegistState(InstanceRegistStateType value) {
        this.registState = value;
    }

    /**
     * stateプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link InstanceStateKind }
     *     
     */
    public InstanceStateKind getState() {
        return state;
    }

    /**
     * stateプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceStateKind }
     *     
     */
    public void setState(InstanceStateKind value) {
        this.state = value;
    }

    /**
     * Gets the value of the tags property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tags property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTags().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Tag }
     * 
     * 
     */
    public List<Tag> getTags() {
        if (tags == null) {
            tags = new ArrayList<Tag>();
        }
        return this.tags;
    }

    /**
     * templateIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemplateId() {
        return templateId;
    }

    /**
     * templateIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemplateId(String value) {
        this.templateId = value;
    }

    /**
     * updateDateプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUpdateDate() {
        return updateDate;
    }

    /**
     * updateDateプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUpdateDate(Long value) {
        this.updateDate = value;
    }

    /**
     * updateUserプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUpdateUser() {
        return updateUser;
    }

    /**
     * updateUserプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUpdateUser(String value) {
        this.updateUser = value;
    }

    /**
     * zoneプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getZone() {
        return zone;
    }

    /**
     * zoneプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setZone(String value) {
        this.zone = value;
    }

}
